import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Reports an event and activates site automations with the specified trigger key.
 *
 *
 * Only the app that created a trigger can report events for it.
 * This means other apps can't report events for your triggers,
 * and you can't report events for another app's triggers.
 *
 * If your app supports canceling events,
 * `externalEntityId` must be provided.
 * `externalEntityId` is required when calling [cancelEvent()](#cancel-event).
 */
export declare function reportEvent(payload: object): RequestOptionsFactory<any>;
/** Bulk reports events and activates site automations with the specified trigger key. */
export declare function bulkReportEvent(payload: object): RequestOptionsFactory<any>;
/** Bulk cancels any remaining actions for a trigger and external entities. */
export declare function bulkCancelEvent(payload: object): RequestOptionsFactory<any>;
/**
 * Cancels any remaining actions for a trigger and external entity.
 *
 *
 * Events are not cancelable by default.
 * To make an event cancelable,
 * you must first pass an `externalEntityId`
 * and the applicable `triggerKey` to [reportEvent()](#report-event).
 * When you call cancelEvent() with the same `externalEntityId` and `triggerKey`,
 * the event is canceled,
 * as are all other events that share the `externalEntityId` and `triggerKey`.
 */
export declare function cancelEvent(payload: object): RequestOptionsFactory<any>;
