import { HttpClient } from '@wix/sdk-types';
import { BulkCancelEventResponse, BulkReportEventResponse, EventInfo, ReportEventOptions, ReportEventResponse } from './automations-v2-activation-activations.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function reportEvent(httpClient: HttpClient): ReportEventSignature;
interface ReportEventSignature {
    /**
     * Reports an event and activates site automations with the specified trigger key.
     *
     *
     * Only the app that created a trigger can report events for it.
     * This means other apps can't report events for your triggers,
     * and you can't report events for another app's triggers.
     *
     * If your app supports canceling events,
     * `externalEntityId` must be provided.
     * `externalEntityId` is required when calling [cancelEvent()](#cancel-event).
     * @param - Trigger key as defined in your app's trigger configuration
     * in the app dashboard.
     * For example, `form_submitted` or `invoice_due`.
     */
    (triggerKey: string, options?: ReportEventOptions | undefined): Promise<ReportEventResponse>;
}
export declare function bulkReportEvent(httpClient: HttpClient): BulkReportEventSignature;
interface BulkReportEventSignature {
    /**
     * Bulk reports events and activates site automations with the specified trigger key.
     * @param - Trigger key as defined in your app's trigger configuration
     * in the app dashboard.
     * For example, `form_submitted` or `invoice_due`.
     * @param - Repeated list of event details for bulk reporting.
     */
    (triggerKey: string, eventsInfo: EventInfo[]): Promise<BulkReportEventResponse>;
}
export declare function bulkCancelEvent(httpClient: HttpClient): BulkCancelEventSignature;
interface BulkCancelEventSignature {
    /**
     * Bulk cancels any remaining actions for a trigger and external entities.
     * @param - Trigger key whose events you want to cancel.
     * For example, `form_submitted` or `invoice_due`.
     * @param - Repeated list of external_entity_id, representing the related resources' IDs.
     */
    (triggerKey: string, externalEntityIds: string[]): Promise<BulkCancelEventResponse>;
}
export declare function cancelEvent(httpClient: HttpClient): CancelEventSignature;
interface CancelEventSignature {
    /**
     * Cancels any remaining actions for a trigger and external entity.
     *
     *
     * Events are not cancelable by default.
     * To make an event cancelable,
     * you must first pass an `externalEntityId`
     * and the applicable `triggerKey` to [reportEvent()](#report-event).
     * When you call cancelEvent() with the same `externalEntityId` and `triggerKey`,
     * the event is canceled,
     * as are all other events that share the `externalEntityId` and `triggerKey`.
     * @param - Trigger key whose event you want to cancel.
     * For example, `form_submitted` or `invoice_due`.
     * @param - ID of the related resource in GUID format.
     * For example, `fc81a355-3429-50fc-a4c7-def486e828f3`.
     *
     * Typically, this ID is defined in your system,
     * but you can also use any Wix resource GUID,
     * such as contact ID, member ID, or invoice ID.
     * See
     * [Choose the right `externalEntityId`](https://dev.wix.com/docs/rest/business-management/automations/triggered-events/reporting-and-canceling-events#choose-the-right-externalentityid)
     * for more information.
     */
    (triggerKey: string, externalEntityId: string): Promise<void>;
}
export { Action, ActionActionOneOf, ActionAttributes, ActionCodeSnippet, ActionCompletedRequest, ActionData, ActionEvent, ActionRetryRequest, ActionSettings, ActionsData, Activation, ActivationActionStatusChanged, ActivationActionStatusChangedInfoOneOf, ActivationActionStatusChangedStatus, ActivationActionStatusChangedStatusInfoOneOf, ActivationContext, ActivationContinuedAfterSchedule, ActivationRequest, ActivationResumeAfterDelay, ActivationScheduleCompleted, ActivationScheduleRequested, ActivationSource, ActivationSourceOfOneOf, ActivationStatusChanged, ActivationStatusChangedFailedStatusInfo, ActivationStatusChangedStartedStatusInfo, ActivationStatusChangedStatus, ActivationStatusChangedStatusInfoOneOf, AppDefinedAction, AppDefinedActionInfo, ApplicationError, ApplicationOrigin, AsyncAction, AuditInfo, AuditInfoIdOneOf, Automation, AutomationConfiguration, AutomationConfigurationAction, AutomationConfigurationActionInfoOneOf, AutomationConfigurationStatus, AutomationIdentifier, AutomationInfo, AutomationInfoOriginInfoOneOf, AutomationInfoTriggerInfo, AutomationOriginInfoOneOf, AutomationSettings, BatchActivationRequest, BlockType, BulkActionMetadata, BulkCancelEventRequest, BulkCancelEventResponse, BulkCancelEventResult, BulkReportEventRequest, BulkReportEventResponse, BulkReportEventResult, CancelEventRequest, CancelEventResponse, CancelPendingScheduleRequest, CancelPendingScheduleRequestByOneOf, CancelPendingScheduleResponse, CancellationReason, CancelledStatusInfo, Case, CodeConditionAction, CodeConditionActionInfo, CodeConditionFilter, CodeSnippet, CodeSnippetLanguage, ConditionAction, ConditionActionInfo, ConditionBlock, ConditionExpressionGroup, ConditionFilter, ConsumeReportEventRequest, Delay, DelayAction, DelayActionInfo, DelayHelper, DelayOfOneOf, Domain, DomainEvent, DomainEventBodyOneOf, DraftInfo, Empty, EndedStatusInfo, EndedStatusInfoAppDefinedActionInfo, EndedStatusInfoTypeInfoOneOf, Enrichment, Enrichments, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, ErrorReason, EventInfo, ExecuteFromActionRequest, ExecuteFromActionResponse, ExpressionEvaluationResult, ExtendedFields, FailedStatusInfo, FailureInfo, Filter, FilterValueSelection, FilterableAppDefinedActions, FutureDateActivationOffset, Idempotency, IdentificationData, IdentificationDataIdOneOf, IdentifierType, Identity, IfFilter, InitiatedStatusInfo, InvokedAsyncStatusInfo, InvokedAsyncStatusInfoAppDefinedActionInfo, InvokedAsyncStatusInfoTypeInfoOneOf, ItemMetadata, Language, MessageEnvelope, Metadata, Operator, Origin, Output, OutputAction, Path, PreinstalledIdentifier, PreinstalledOrigin, RateLimit, RateLimitAction, RateLimitActionInfo, RateLimiting, RefreshPayloadRequest, RefreshPayloadResponse, ReportActionInvocationCompletedRequest, ReportActionInvocationCompletedRequestStatusInfoOneOf, ReportActionInvocationCompletedResponse, ReportDomainEventRequest, ReportDomainEventResponse, ReportEventOptions, ReportEventRequest, ReportEventResponse, RestoreInfo, ResumeAfterAsyncActionCompleted, ResumeAfterAsyncActionCompletedStatusInfoOneOf, RetryInfo, RunAutomationRequest, RunAutomationResponse, Runtime, RuntimeStatus, Schedule, ScheduleActivationRequested, ScheduleRequest, ScheduleResponse, ScheduleStatus, ScheduledAction, ScheduledStatusInfo, Scheduler, Service, ServiceMapping, SetVariables, SetVariablesAction, SetVariablesActionInfo, SimpleDelay, SkipReason, SkippedStatusInfo, SpiAction, SplitAction, StartedStatusInfo, StartedStatusInfoAppDefinedActionInfo, StartedStatusInfoDelayActionInfo, StartedStatusInfoTypeInfoOneOf, Status, SuccessInfo, SwitchFilter, SystemHelper, SystemHelperHelperOneOf, Target, TimeUnit, Trigger, TriggerInfo, Type, Units, UpdatePendingSchedulesPayloadRequest, UpdatePendingSchedulesPayloadResponse, V1RunAutomationRequest, V1RunAutomationRequestIdentifierOneOf, V1RunAutomationResponse, WebhookIdentityType, } from './automations-v2-activation-activations.universal.js';
