import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixAutomationsEsbResolverV1EsbConfigResolverUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/esb-config-resolver',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/automations/v1/events/report',
                destPath: '/v1/events/report',
            },
            {
                srcPath: '/automations/v1/events/bulk-report',
                destPath: '/v1/events/bulk-report',
            },
            {
                srcPath: '/automations/v1/events/cancel',
                destPath: '/v1/events/cancel',
            },
            {
                srcPath: '/automations/v1/events/bulk-cancel',
                destPath: '/v1/events/bulk-cancel',
            },
        ],
        'platform.rise.ai': [
            {
                srcPath: '/workflows/v1/events/report',
                destPath: '/v1/events/report',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_automations_activations';
/**
 * Reports an event and activates site automations with the specified trigger key.
 *
 *
 * Only the app that created a trigger can report events for it.
 * This means other apps can't report events for your triggers,
 * and you can't report events for another app's triggers.
 *
 * If your app supports canceling events,
 * `externalEntityId` must be provided.
 * `externalEntityId` is required when calling [cancelEvent()](#cancel-event).
 */
export function reportEvent(payload) {
    function __reportEvent({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.activation',
            method: 'POST',
            methodFqn: 'wix.automations.esb.resolver.v1.EsbConfigResolver.ReportEvent',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsEsbResolverV1EsbConfigResolverUrl({
                protoPath: '/v1/events/report',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __reportEvent;
}
/** Bulk reports events and activates site automations with the specified trigger key. */
export function bulkReportEvent(payload) {
    function __bulkReportEvent({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.activation',
            method: 'POST',
            methodFqn: 'wix.automations.esb.resolver.v1.EsbConfigResolver.BulkReportEvent',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsEsbResolverV1EsbConfigResolverUrl({
                protoPath: '/v1/events/bulk-report',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkReportEvent;
}
/** Bulk cancels any remaining actions for a trigger and external entities. */
export function bulkCancelEvent(payload) {
    function __bulkCancelEvent({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.activation',
            method: 'POST',
            methodFqn: 'wix.automations.esb.resolver.v1.EsbConfigResolver.BulkCancelEvent',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsEsbResolverV1EsbConfigResolverUrl({
                protoPath: '/v1/events/bulk-cancel',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkCancelEvent;
}
/**
 * Cancels any remaining actions for a trigger and external entity.
 *
 *
 * Events are not cancelable by default.
 * To make an event cancelable,
 * you must first pass an `externalEntityId`
 * and the applicable `triggerKey` to [reportEvent()](#report-event).
 * When you call cancelEvent() with the same `externalEntityId` and `triggerKey`,
 * the event is canceled,
 * as are all other events that share the `externalEntityId` and `triggerKey`.
 */
export function cancelEvent(payload) {
    function __cancelEvent({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.activation',
            method: 'POST',
            methodFqn: 'wix.automations.esb.resolver.v1.EsbConfigResolver.CancelEvent',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsEsbResolverV1EsbConfigResolverUrl({
                protoPath: '/v1/events/cancel',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __cancelEvent;
}
//# sourceMappingURL=automations-v2-activation-activations.http.js.map